#ifndef KUSERDATAREQUESTDLG_H
#define KUSERDATAREQUESTDLG_H
/** KWlan
 *
 *  This File is part of KWlan, a network Manager for KDE.
 *  KWlan is distributed under LGPL license.
 *
 *	@author Thomas Michel <tom.michel@arcor.de>
 */

#include "kuserdatarequest.h"

class KWlanInterface;

class KUserDataRequestDlg : public KUserDataRequest
{
  Q_OBJECT

public:
  KUserDataRequestDlg(QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
  ~KUserDataRequestDlg();
  /*$PUBLIC_FUNCTIONS$*/
  virtual int           setParams( KWlanInterface *m_interface, const char * requestMessage );

public slots:
  /*$PUBLIC_SLOTS$*/
  virtual void          sendReply();

protected:
  /*$PROTECTED_FUNCTIONS$*/

protected slots:
  /*$PROTECTED_SLOTS$*/

private:
    KWlanInterface *m_interface;
    int m_networkId;
    QString m_field;
};

#endif

